#
# spec file for cassandra
#
# Copyright (c) 2017 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

%if ! %{defined _fillupdir}
%define _fillupdir /var/adm/fillup-templates
%endif

%define _pkgvendor apache
%define _pkg cassandra
%define _pkgname %{_pkgvendor}-%{_pkg}

# only needed for < 1310
%{!?_tmpfilesdir:%global _tmpfilesdir /usr/lib/tmpfiles.d}

%define _fwdefdir /etc/sysconfig/SuSEfirewall2.d/services

Name:           cassandra
Version:        3.11.2
Release:        4.10
License:        Apache-2.0
Summary:        A scalable, eventually consistent, distributed, structured key-value store
Url:            http://cassandra.apache.org/
Group:          Development/Libraries
Source:         http://www.us.apache.org/dist/%{_pkg}/%{version}/%{_pkgvendor}-%{_pkg}-%{version}-src.tar.gz
Source2:        cassandra.limits
Source3:        cassandra.sysconfig
Source4:        cassandra.fw
Source5:        cassandra.service.suse
Source6:        build.sh
BuildRequires:  fdupes
BuildRequires:  python-devel
BuildRequires:  python-Sphinx
BuildRequires:  python-Cython
# This package is required to provide the various jars the build would
# otherwise would attempt to download from the Internet (which will fail in the
# OBS environment). If you update the Cassandra package itself you will
# probably need to regenerate this kit package (at a minimum you will have to
# bump its version). You will find instructions on updating it in its
# README.building file.
BuildRequires:  %{_pkg}-kit = %{version}
%ifarch s390x
BuildRequires:  java-1_8_0-ibm-devel
BuildRequires:  java-1_8_0-ibm
%else
BuildRequires:  java-1_8_0-openjdk-devel
BuildRequires:  java-1_8_0-openjdk
%endif
%if 0%{?suse_version} >= 1210
BuildRequires:  systemd
%{?systemd_requires}
%define has_systemd 1
%endif
Requires:       java-1_8_0-openjdk
Requires:       jpackage-utils
Provides:       apache-cassandra
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
#BuildArch:      noarch
PreReq:         %fillup_prereq
PreReq:         %insserv_prereq

%description
Cassandra brings together the distributed systems technologies from
Dynamo and the data model from Google's BigTable. Like Dynamo,
Cassandra is eventually consistent. Like BigTable, Cassandra provides
a ColumnFamily-based data model richer than typical key/value systems.

For more information see http://cassandra.apache.org/

%package javadoc
Summary:        Javadoc for %{_pkg}
Requires:       %{name} = %{version}

%description javadoc
Java documentation for %{name}

%package tools
Summary:        Extra tools for Cassandra
Requires:       %{name} = %{version}

%description tools
This package contains extra tools for working with Cassandra clusters.

%prep
%setup -q -n %{_pkgname}-%{version}-src
cp -Rf %{_datadir}/tetra ../kit
# remove windows scripts
find . -name \*.ps1 -delete
find . -name \*.bat -delete

%build
sh %{SOURCE6}

# build python library
pushd pylib
python setup.py build
popd

%install
# https://en.opensuse.org/openSUSE:Packaging_Java#bytecode_version_error
%if 0%{?suse_version} == 1110
export NO_BRP_CHECK_BYTECODE_VERSION=true
%endif

install -d -m 0755 %{buildroot}%{_sysconfdir}/default
install -d -m 0755 %{buildroot}%{_sysconfdir}/%{_pkg}/conf
install -d -m 0755 %{buildroot}%{_sysconfdir}/security/limits.d
install -d -m 0755 %{buildroot}%{_bindir}
install -d -m 0755 %{buildroot}%{_unitdir}
install -d -m 0755 %{buildroot}%{_sbindir}
install -d -m 0755 %{buildroot}%{_datarootdir}/%{_pkg}
install -d -m 0755 %{buildroot}%{_datarootdir}/%{_pkg}/lib
install -d -m 0755 %{buildroot}%{_localstatedir}/log/%{_pkg}
install -d -m 0755 %{buildroot}%{_localstatedir}/lib/%{_pkg}
install -d -m 0755 %{buildroot}%{_localstatedir}/lib/%{_pkg}/{commitlog,data,saved_caches}
%if 0%{?suse_version} == 1315
install -d -m 0755 %{buildroot}%{_localstatedir}/run/%{_pkg}
%else
install -d -m 0755 %{buildroot}/run/%{_pkg}
%endif
install -d -m 0755 %{buildroot}%{_fillupdir}

install -m 0755 bin/cassandra       %{buildroot}%{_sbindir}
install -m 0755 bin/cqlsh           %{buildroot}%{_bindir}
install -m 0755 bin/cqlsh.py        %{buildroot}%{_bindir}
install -m 0755 bin/debug-cql       %{buildroot}%{_bindir}
install -m 0755 bin/nodetool        %{buildroot}%{_bindir}
install -m 0755 bin/sstableloader   %{buildroot}%{_bindir}
install -m 0755 bin/sstablescrub    %{buildroot}%{_bindir}
install -m 0755 bin/sstableupgrade  %{buildroot}%{_bindir}
install -m 0755 bin/sstableutil     %{buildroot}%{_bindir}
install -m 0755 bin/sstableverify   %{buildroot}%{_bindir}
install -m 0755 bin/stop-server     %{buildroot}%{_bindir}

install -m 0755 tools/bin/sstablesplit           %{buildroot}%{_bindir}
install -m 0755 tools/bin/cassandra-stress       %{buildroot}%{_bindir}
install -m 0755 tools/bin/cassandra-stressd      %{buildroot}%{_bindir}
install -m 0755 tools/bin/compaction-stress      %{buildroot}%{_bindir}
install -m 0755 tools/bin/sstabledump            %{buildroot}%{_bindir}
install -m 0755 tools/bin/sstableexpiredblockers %{buildroot}%{_bindir}
install -m 0755 tools/bin/sstablelevelreset      %{buildroot}%{_bindir}
install -m 0755 tools/bin/sstablemetadata        %{buildroot}%{_bindir}
install -m 0755 tools/bin/sstableofflinerelevel  %{buildroot}%{_bindir}
install -m 0755 tools/bin/sstablerepairedset     %{buildroot}%{_bindir}
install -m 0755 tools/bin/sstablesplit           %{buildroot}%{_bindir}

# This is not part of the binary release tarball, so remove it here as well:
rm lib/maven-ant-tasks-*.jar

mv build/tools/lib/* %{buildroot}%{_datarootdir}/%{_pkg}/lib/

# set home and conf
sed -i -e '/x$CASSANDRA_HOME/i CASSANDRA_HOME=/usr/share/cassandra' \
       -e '/x$CASSANDRA_CONF/i CASSANDRA_CONF=/etc/cassandra/conf' \
        bin/cassandra.in.sh
install -m 0644 bin/cassandra.in.sh %{buildroot}%{_datarootdir}/%{_pkg}

mv conf/*     %{buildroot}%{_sysconfdir}/%{_pkg}/conf
cp lib/*.jar lib/*.zip  %{buildroot}%{_datarootdir}/%{_pkg}/lib/
cp build/%{_pkgname}-%{version}-SNAPSHOT.jar %{buildroot}%{_datarootdir}/%{_pkg}/lib/
cp build/%{_pkgname}-thrift-%{version}-SNAPSHOT.jar %{buildroot}%{_datarootdir}/%{_pkg}/lib/

install -m 0644 %{SOURCE2} %{buildroot}%{_sysconfdir}/security/limits.d/%{_pkg}.conf
install -m 0644 %{SOURCE3} %{buildroot}%{_fillupdir}/sysconfig.%{_pkg}
install -m 0644 %{SOURCE5} %{buildroot}%{_unitdir}/%{_pkg}.service

# create symlinks
pushd  %{buildroot}%{_datarootdir}/%{_pkg}
ln -s %{_localstatedir}/lib/%{_pkg} data
ln -s %{_localstatedir}/log/%{_pkg} logs
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rc%{name}
popd

install -d -m 0755 %{buildroot}%{_fwdefdir}
install -m 0644 %{SOURCE4} %{buildroot}%{_fwdefdir}/%{_pkg}

%fdupes %{buildroot}

# install python library
pushd pylib
python setup.py install --prefix=%{_prefix} --root=%{buildroot}
popd

%pre
groupadd -r %{_pkg} 2>/dev/null || :
useradd -r -g %{_pkg} -s /bin/bash -c "Cassandra User" \
        -d %{_datarootdir}/%{_pkg} %{_pkg} 2>/dev/null || :

%service_add_pre %{_pkg}.service

%post
%fillup_only -n %{_pkg}
%service_add_post   %{_pkg}.service

%preun
%service_del_preun  %{_pkg}.service
%stop_on_removal %{_pkg}

%postun
%service_del_postun unbound-keygen.service unbound.service

%files
%defattr(-,root,root)
%doc CHANGES.txt LICENSE.txt NEWS.txt NOTICE.txt interface lib/licenses
%dir %attr(0755 cassandra,cassandra) %{_sysconfdir}/%{_pkg}
%dir %attr(0755 cassandra,cassandra) %{_sysconfdir}/%{_pkg}/conf
%config(noreplace) %attr(0644 cassandra,cassandra) %{_sysconfdir}/%{_pkg}/conf/*
%dir %{_sysconfdir}/security/limits.d
%config(noreplace) %attr(0644 root,root) %{_sysconfdir}/security/limits.d/%{_pkg}.conf
%{_fwdefdir}/%{_pkg}

%{_bindir}/cqlsh
%{_bindir}/cqlsh.py
%{_bindir}/debug-cql
%{_bindir}/nodetool
%{_bindir}/sstableloader
%{_bindir}/sstablescrub
%{_bindir}/sstableupgrade
%{_bindir}/sstableutil
%{_bindir}/sstableverify
%{_bindir}/stop-server
%{_sbindir}/cassandra

%{_datarootdir}/%{_pkg}
%attr(0755 cassandra,cassandra) %{_localstatedir}/log/%{_pkg}
%attr(0755 cassandra,cassandra) %{_localstatedir}/lib/%{_pkg}
%if 0%{?suse_version} == 1315
%ghost %{_localstatedir}/run/%{_pkg}
%else
%ghost /run/%{_pkg}
%endif
%{_fillupdir}/sysconfig.%{_pkg}

%{_unitdir}/%{_pkg}.service
%{_sbindir}/rc%{name}

# python library
%{python_sitearch}/*

%files tools
%defattr(-,root,root)
%{_bindir}/cassandra-stress
%{_bindir}/cassandra-stressd
%{_bindir}/compaction-stress 
%{_bindir}/sstabledump
%{_bindir}/sstablelevelreset
%{_bindir}/sstablemetadata
%{_bindir}/sstableofflinerelevel
%{_bindir}/sstablesplit
%{_bindir}/sstablerepairedset
%{_bindir}/sstableexpiredblockers

%files javadoc
%defattr(-,root,root)
%doc javadoc

%changelog
* Thu Apr  5 2018 SGrasley@suse.com
- Set systemd service to restart on-failure (bsc#1087794)
* Wed Mar 14 2018 aplanas@suse.com
- Update cassandra to 3.11.2 (bsc#1085265)
  * Fix ReadCommandTest (CASSANDRA-14234)
  * Remove trailing period from latency reports at keyspace level
    (CASSANDRA-14233)
  * Backport CASSANDRA-13080: Use new token allocation for non
    bootstrap case as well (CASSANDRA-14212)
  * Remove dependencies on JVM internal classes from JMXServerUtils
    (CASSANDRA-14173)
  * Add DEFAULT, UNSET, MBEAN and MBEANS to `ReservedKeywords`
    (CASSANDRA-14205)
  * Add Unittest for schema migration fix (CASSANDRA-14140)
  * Print correct snitch info from nodetool describecluster
    (CASSANDRA-13528)
  * Close socket on error during connect on OutboundTcpConnection
    (CASSANDRA-9630)
  * Enable CDC unittest (CASSANDRA-14141)
  * Acquire read lock before accessing CompactionStrategyManager
    fields (CASSANDRA-14139)
  * Split CommitLogStressTest to avoid timeout (CASSANDRA-14143)
  * Avoid invalidating disk boundaries unnecessarily (CASSANDRA-14083)
  * Avoid exposing compaction strategy index externally
    (CASSANDRA-14082)
  * Prevent continuous schema exchange between 3.0 and 3.11 nodes
    (CASSANDRA-14109)
  * Fix imbalanced disks when replacing node with same address with
    JBOD (CASSANDRA-14084)
  * Reload compaction strategies when disk boundaries are invalidated
    (CASSANDRA-13948)
  * Remove OpenJDK log warning (CASSANDRA-13916)
  * Prevent compaction strategies from looping indefinitely
    (CASSANDRA-14079)
  * Cache disk boundaries (CASSANDRA-13215)
  * Add asm jar to build.xml for maven builds (CASSANDRA-11193)
  * Round buffer size to powers of 2 for the chunk cache
    (CASSANDRA-13897)
  * Update jackson JSON jars (CASSANDRA-13949)
  * Avoid locks when checking LCS fanout and if we should defrag
    (CASSANDRA-13930)
  * Correctly count range tombstones in traces and tombstone
    thresholds (CASSANDRA-8527)
- Drop javadoc-encoding.patch patch (included in 3.11.2)
- Use %%_fillupdir macro
* Wed Mar 14 2018 ro@suse.de
- use IBM java on s390x to allow successful build
* Tue Jan 16 2018 johannes.grassler@suse.com
- Hardwire Java requires to 1.8 since Cassandra will not build
  with 1.9 and up).
* Tue Jan  9 2018 johannes.grassler@suse.com
- Remove commented macros
* Tue Jan  9 2018 johannes.grassler@suse.com
- Switch to pure systemd for service startup
* Mon Jan  8 2018 johannes.grassler@suse.com
- Switch to building from Cassandra source tarball and
  cassandra-kit package
- Add javadoc-encoding.patch (fixes Javadoc documentation build)
* Mon Dec  4 2017 sgrasley@suse.com
- Version bump to cassandra-3.11.1 (Fix memory leak in 3.11.0)
* Thu Nov 30 2017 sgrasley@suse.com
- version bump to cassandra-3.11.0
* Thu Feb 23 2017 nicolas.bock@suse.com
- Cleanup
* Thu Feb 23 2017 nicolas.bock@suse.com
- Removed old version
* Thu Feb 23 2017 nicolas.bock@suse.com
- Version bump to cassandra-2.2.8
